@@ -1,7 +1,12 @@
 # Licensed under the MIT License
 # https://github.com/craigahobbs/simple-git-changelog/blob/main/LICENSE
 
+"""
+simple-git-changelog top-level script environment
+"""
+
 from .main import main
 
-if __name__ == '__main__':
-    main() # pragma: no cover
+
+if __name__ == '__main__': # pragma: no cover
+    main()
